@@ -452,11 +452,11 @@ TOTAL_NODES = {}""".format(K_0, D_0, L_S, D_S, pressure, force_per_node, r_inner
         cmd = call(["saenopy","CONFIG", "{}//config.txt".format(os.path.abspath(outfolder))])
 
     # copy result files from "*_py2" folder
-    for filename in glob(outfolder+'_py2/*.*'):
-        shutil.copy(filename, outfolder)
+    # for filename in glob(outfolder+'_py2/*.*'):
+    #     shutil.copy(filename, outfolder)
 
-    # remove "*_py2" folder
-    shutil.rmtree(outfolder+'_py2')
+    # # remove "*_py2" folder
+    # shutil.rmtree(outfolder+'_py2')
 
 
 def distribute(func, const_args, var_arg='pressure', start=0.1, end=1000, n=120, log_scaling=True, n_cores=None):
@@ -715,7 +715,7 @@ def plot_lookup_table(lookup_table, pressure=[0,10000], log_scale = True, distan
     
     plt.grid(False) 
     plt.ylabel('Normalized matrix deformations (u/r₀)', fontsize=10)           # plt.ylabel('Normed Deformation', fontsize=14)
-    plt.xlabel('Normalized distance from organoid center (r/r₀)', fontsize=10) # plt.xlabel('Normed Distance', fontsize=14)
+    plt.xlabel('Normalized distance to center (r/r₀)', fontsize=10) # plt.xlabel('Normed Distance', fontsize=14)
     
     # make a colorbar
     cbar= plt.colorbar(sm, )
